@@ -23,11 +23,15 @@ class DatasetDescriptor(object):
             input_shape,
             output_shape,
             samples_count,
+            samples_train,
+            samples_test
     ):
         self.__dataset_name = dataset_name
         self.__input_shape = input_shape
         self.__output_shape = output_shape
         self.__samples_count = samples_count
+        self.__samples_train = samples_train
+        self.__samples_test = samples_test
         self.__input_size = reduce(lambda l, r: l * r, input_shape)
         self.__output_size = reduce(lambda l, r: l * r, output_shape)
 
@@ -47,6 +51,14 @@ class DatasetDescriptor(object):
     def samples_count(self):
         return self.__samples_count
 
+    @property
+    def samples_train(self):
+        return self.__samples_train
+
+    @property
+    def samples_test(self):
+        return self.__samples_test
+
     @property
     def input_size(self):
         return self.__input_size
@@ -139,7 +151,9 @@ class DataStoreClient(object):
         jsn = response.json()
         return DatasetDescriptor(
             self.dataset_name,
-            tuple(list(map(lambda x: int(x), jsn["input_size"]))),
-            tuple(list(map(lambda x: int(x), jsn["output_size"]))),
-            int(jsn["size"])
+            tuple(list(map(lambda x: int(x), jsn["input_shape"]))),
+            tuple(list(map(lambda x: int(x), jsn["output_shape"]))),
+            int(jsn["size"]),
+            int(jsn["size_train"]),
+            int(jsn["size_test"])
         )
